@@ -1,5 +1,5 @@
-tbl_subset_matrix <- function(x, j, j_arg) {
-  cells <- matrix_to_cells(j, x, j_arg)
+tbl_subset_matrix <- function(x, j, j_arg, call = caller_env()) {
+  cells <- matrix_to_cells(j, x, j_arg, call)
   col_idx <- cells_to_col_idx(cells)
 
   if (is_empty(col_idx)) {
@@ -12,18 +12,18 @@ tbl_subset_matrix <- function(x, j, j_arg) {
   unname(vec_c(!!!values, .name_spec = ~.x))
 }
 
-tbl_subassign_matrix <- function(x, j, value, j_arg, value_arg) {
+tbl_subassign_matrix <- function(x, j, value, j_arg, value_arg, call = caller_env()) {
   # FIXME: use size argument in vctrs >= 0.3.0
 
   if (!vec_is(value)) {
-    cnd_signal(error_subset_matrix_scalar_type(j_arg, value_arg))
+    abort_subset_matrix_scalar_type(j_arg, value_arg, call)
   }
 
   if (vec_size(value) != 1) {
-    cnd_signal(error_subset_matrix_must_be_scalar(j_arg, value_arg))
+    abort_subset_matrix_must_be_scalar(j_arg, value_arg, call)
   }
 
-  cells <- matrix_to_cells(j, x, j_arg)
+  cells <- matrix_to_cells(j, x, j_arg, call)
   col_idx <- cells_to_col_idx(cells)
 
   withCallingHandlers(
@@ -31,19 +31,19 @@ tbl_subassign_matrix <- function(x, j, value, j_arg, value_arg) {
       x[[j]] <- vectbl_assign(x[[j]], cells[[j]], value)
     },
     vctrs_error_incompatible_type = function(cnd) {
-      cnd_signal(error_assign_incompatible_type(x, rep(list(value), j), j, value_arg, cnd_message(cnd)))
+      abort_assign_incompatible_type(x, rep(list(value), j), j, value_arg, cnd, call = call)
     }
   )
 
   x
 }
 
-matrix_to_cells <- function(j, x, j_arg) {
+matrix_to_cells <- function(j, x, j_arg, call = caller_env()) {
   if (!is_bare_logical(j)) {
-    cnd_signal(error_subset_matrix_must_be_logical(j_arg))
+    abort_subset_matrix_must_be_logical(j_arg, call)
   }
   if (!identical(dim(j), dim(x))) {
-    cnd_signal(error_subset_matrix_must_have_same_dimensions(j_arg))
+    abort_subset_matrix_must_have_same_dimensions(j_arg, call)
   }
 
   # Need unlist(list(...)) because apply() isn't type stable if the return
@@ -62,30 +62,30 @@ cells_to_col_idx <- function(cells) {
 
 # Errors ------------------------------------------------------------------
 
-error_subset_matrix_must_be_logical <- function(j_arg) {
-  tibble_error(paste0(
+abort_subset_matrix_must_be_logical <- function(j_arg, call = caller_env()) {
+  tibble_abort(call = call, paste0(
     "Subscript ", tick(as_label(j_arg)),
     " is a matrix, it must be of type logical."
   ))
 }
 
-error_subset_matrix_must_have_same_dimensions <- function(j_arg) {
-  tibble_error(paste0(
+abort_subset_matrix_must_have_same_dimensions <- function(j_arg, call = caller_env()) {
+  tibble_abort(call = call, paste0(
     "Subscript ", tick(as_label(j_arg)),
     " is a matrix, it must have the same dimensions as the input."
   ))
 }
 
-error_subset_matrix_scalar_type <- function(j_arg, value_arg) {
-  tibble_error(paste0(
+abort_subset_matrix_scalar_type <- function(j_arg, value_arg, call = caller_env()) {
+  tibble_abort(call = call, paste0(
     "Subscript ", tick(as_label(j_arg)),
     " is a matrix, the data ", tick(as_label(value_arg)),
     " must be a vector of size 1."
   ))
 }
 
-error_subset_matrix_must_be_scalar <- function(j_arg, value_arg) {
-  tibble_error(paste0(
+abort_subset_matrix_must_be_scalar <- function(j_arg, value_arg, call = caller_env()) {
+  tibble_abort(call = call, paste0(
     "Subscript ", tick(as_label(j_arg)),
     " is a matrix, the data ", tick(as_label(value_arg)),
     " must have size 1."
