@@ -211,7 +211,7 @@ is.tibble <- function(x) {
   is_tibble(x)
 }
 
-tibble_quos <- function(xs, .rows, .name_repair, single_row = FALSE) {
+tibble_quos <- function(xs, .rows, .name_repair, single_row = FALSE, call = caller_env()) {
   # Evaluate each column in turn
   col_names <- given_col_names <- names2(xs)
   empty_col_names <- which(col_names == "")
@@ -234,14 +234,14 @@ tibble_quos <- function(xs, .rows, .name_repair, single_row = FALSE) {
       if (single_row) {
         if (vec_is(res)) {
           if (vec_size(res) != 1) {
-            cnd_signal(error_tibble_row_size_one(j, given_col_names[[j]], vec_size(res)))
+            abort_tibble_row_size_one(j, given_col_names[[j]], vec_size(res))
           }
         } else {
           res <- list(res)
         }
       } else {
         # 657
-        res <- check_valid_col(res, col_names[[j]], j)
+        res <- check_valid_col(res, col_names[[j]], j, call)
 
         lengths[[j]] <- current_size <- vec_size(res)
         if (is.null(first_size)) {
@@ -256,7 +256,7 @@ tibble_quos <- function(xs, .rows, .name_repair, single_row = FALSE) {
 
           first_size <- current_size
         } else {
-          res <- vectbl_recycle_rows(res, first_size, j, given_col_names[[j]])
+          res <- vectbl_recycle_rows(res, first_size, j, given_col_names[[j]], call)
         }
       }
 
@@ -271,16 +271,16 @@ tibble_quos <- function(xs, .rows, .name_repair, single_row = FALSE) {
   output <- output[!is_null]
 
   output <- splice_dfs(output)
-  output <- set_repaired_names(output, repair_hint = TRUE, .name_repair = .name_repair)
+  output <- set_repaired_names(output, repair_hint = TRUE, .name_repair = .name_repair, call = call)
 
   new_tibble(output, nrow = first_size %||% 0L)
 }
 
-check_valid_col <- function(x, name, pos) {
+check_valid_col <- function(x, name, pos, call) {
   if (name == "") {
-    ret <- check_valid_cols(list(x), pos = pos)
+    ret <- check_valid_cols(list(x), pos = pos, call = call)
   } else {
-    ret <- check_valid_cols(set_names(list(x), name))
+    ret <- check_valid_cols(set_names(list(x), name), call = call)
   }
   invisible(ret[[1]])
 }
@@ -318,7 +318,7 @@ splice_dfs <- function(x) {
   vec_c(!!!x, .name_spec = "{inner}")
 }
 
-vectbl_recycle_rows <- function(x, n, j, name) {
+vectbl_recycle_rows <- function(x, n, j, name, call = caller_env()) {
   size <- vec_size(x)
   if (size == n) return(x)
   if (size == 1) return(vec_recycle(x, n))
@@ -327,25 +327,25 @@ vectbl_recycle_rows <- function(x, n, j, name) {
     name <- j
   }
 
-  cnd_signal(error_incompatible_size(n, name, size, "Existing data"))
+  abort_incompatible_size(n, name, size, "Existing data", call)
 }
 
 # Errors ------------------------------------------------------------------
 
-error_tibble_row_size_one <- function(j, name, size) {
+abort_tibble_row_size_one <- function(j, name, size, call = caller_env()) {
   if (name != "") {
     desc <- tick(name)
   } else {
     desc <- paste0("at position ", j)
   }
 
-  tibble_error(problems(
+  tibble_abort(call = call, problems(
     "All vectors must be size one, use `list()` to wrap.",
     paste0("Column ", desc, " is of size ", size, ".")
   ))
 }
 
-error_incompatible_size <- function(.rows, vars, vars_len, rows_source) {
+abort_incompatible_size <- function(.rows, vars, vars_len, rows_source, call = caller_env()) {
   vars_split <- split(vars, vars_len)
 
   vars_split[["1"]] <- NULL
@@ -364,7 +364,7 @@ error_incompatible_size <- function(.rows, vars, vars_len, rows_source) {
     paste0("Size ", x, ": ", pluralise_commas(text, y))
   })
 
-  tibble_error(bullets(
+  tibble_abort(call = call, bullets(
     "Tibble columns must have compatible sizes:",
     if (!is.null(.rows)) paste0("Size ", .rows, ": ", rows_source),
     problems,
