@@ -6,15 +6,10 @@
     safe_match <<- safe_match_default
   }
 
-  # Simplify once pillar 1.5.0 is on CRAN
-  replace_if_pillar_has(glimpse)
-  replace_if_pillar_has(tbl_sum)
-  register_if_pillar_hasnt(c(
-    "glimpse.default", "glimpse.data.frame", "glimpse.tbl",
-    "tbl_sum.default", "tbl_sum.tbl", "format.tbl", "print.tbl"
-  ))
-
-  vctrs::s3_register("tibble::tbl_sum", "tbl_df")
+  num <<- pillar::num
+  set_num_opts <<- pillar::set_num_opts
+  char <<- pillar::char
+  set_char_opts <<- pillar::set_char_opts
 }
 
 safe_match_3_0 <- function(x, table) {
