@@ -48,13 +48,6 @@ test_that("output test", {
       n = 5L,
       width = 30L
     )
-
-    print_with_mocked_format_body(trunc_mat(df_all, n = 1L, n_extra = 2L, width = 30L))
-
-    print_with_mocked_format_body(trunc_mat(df_all, n = 1L, n_extra = 0L, width = 30L))
-
-    df <- tibble(!!!set_names(c(5, 3), c("mean(x)", "var(x)")))
-    print_with_mocked_format_body(trunc_mat(df, width = 28))
   })
 })
 
@@ -73,9 +66,3 @@ test_that("full output test", {
     print(df, n = 8L, width = 60L)
   })
 })
-
-test_that("big_mark() works for large numbers", {
-  expect_match(big_mark(123), "123")
-  expect_match(big_mark(123456), "123.456")
-  expect_match(big_mark(123456789), "123.456.789")
-})
